@@ -53,43 +53,44 @@
 #include <pyside2_qtcore_python.h>
 
 // Bound library includes
-#include <Qt3DExtras/qmorphphongmaterial.h>
-#include <Qt3DExtras/qspritesheet.h>
-#include <Qt3DExtras/qfirstpersoncameracontroller.h>
-#include <Qt3DExtras/qtorusgeometry.h>
-#include <Qt3DExtras/qdiffusemapmaterial.h>
-#include <Qt3DExtras/qplanemesh.h>
 #include <Qt3DExtras/qskyboxentity.h>
-#include <Qt3DExtras/qspritesheetitem.h>
-#include <Qt3DExtras/qforwardrenderer.h>
-#include <Qt3DExtras/qmetalroughmaterial.h>
-#include <Qt3DExtras/qabstractcameracontroller.h>
-#include <Qt3DExtras/qcuboidmesh.h>
-#include <Qt3DExtras/qdiffusespecularmaterial.h>
-#include <Qt3DExtras/qspritegrid.h>
-#include <Qt3DExtras/qextrudedtextgeometry.h>
-#include <Qt3DExtras/qplanegeometry.h>
-#include <Qt3DExtras/qextrudedtextmesh.h>
-#include <Qt3DExtras/qcylindergeometry.h>
-#include <Qt3DExtras/qtexturematerial.h>
-#include <Qt3DExtras/qconegeometry.h>
-#include <Qt3DExtras/qspheregeometry.h>
-#include <Qt3DExtras/qtext2dentity.h>
-#include <Qt3DExtras/qconemesh.h>
-#include <Qt3DExtras/qcuboidgeometry.h>
-#include <Qt3DExtras/qnormaldiffusemapmaterial.h>
-#include <Qt3DExtras/qspheremesh.h>
-#include <Qt3DExtras/qgoochmaterial.h>
 #include <Qt3DExtras/qtorusmesh.h>
-#include <Qt3DExtras/qpervertexcolormaterial.h>
 #include <Qt3DExtras/qcylindermesh.h>
-#include <Qt3DExtras/qphongalphamaterial.h>
-#include <Qt3DExtras/qt3dwindow.h>
-#include <Qt3DExtras/qdiffusespecularmapmaterial.h>
+#include <Qt3DExtras/qspritesheetitem.h>
+#include <Qt3DExtras/qspheregeometry.h>
+#include <Qt3DExtras/qdiffusemapmaterial.h>
+#include <Qt3DExtras/qspritesheet.h>
+#include <Qt3DExtras/qcylindergeometry.h>
 #include <Qt3DExtras/qnormaldiffusespecularmapmaterial.h>
-#include <Qt3DExtras/qabstractspritesheet.h>
-#include <Qt3DExtras/qphongmaterial.h>
+#include <Qt3DExtras/qconemesh.h>
 #include <Qt3DExtras/qorbitcameracontroller.h>
+#include <Qt3DExtras/qconegeometry.h>
+#include <Qt3DExtras/qcuboidmesh.h>
+#include <Qt3DExtras/qtorusgeometry.h>
+#include <Qt3DExtras/qgoochmaterial.h>
+#include <Qt3DExtras/qt3dwindow.h>
+#include <Qt3DExtras/qfirstpersoncameracontroller.h>
+#include <Qt3DExtras/qdiffusespecularmaterial.h>
+#include <Qt3DExtras/qnormaldiffusemapmaterial.h>
+#include <Qt3DExtras/qnormaldiffusemapalphamaterial.h>
+#include <Qt3DExtras/qplanemesh.h>
+#include <Qt3DExtras/qpervertexcolormaterial.h>
+#include <Qt3DExtras/qextrudedtextgeometry.h>
+#include <Qt3DExtras/qabstractcameracontroller.h>
+#include <Qt3DExtras/qplanegeometry.h>
+#include <Qt3DExtras/qabstractspritesheet.h>
+#include <Qt3DExtras/qspheremesh.h>
+#include <Qt3DExtras/qtexturematerial.h>
+#include <Qt3DExtras/qextrudedtextmesh.h>
+#include <Qt3DExtras/qdiffusespecularmapmaterial.h>
+#include <Qt3DExtras/qphongalphamaterial.h>
+#include <Qt3DExtras/qmetalroughmaterial.h>
+#include <Qt3DExtras/qcuboidgeometry.h>
+#include <Qt3DExtras/qmorphphongmaterial.h>
+#include <Qt3DExtras/qphongmaterial.h>
+#include <Qt3DExtras/qforwardrenderer.h>
+#include <Qt3DExtras/qspritegrid.h>
+#include <Qt3DExtras/qtext2dentity.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -130,26 +131,27 @@ enum : int {
     SBK_QT3DEXTRAS_QGOOCHMATERIAL_IDX                        = 17,
     SBK_QT3DEXTRAS_QMETALROUGHMATERIAL_IDX                   = 18,
     SBK_QT3DEXTRAS_QMORPHPHONGMATERIAL_IDX                   = 19,
-    SBK_QT3DEXTRAS_QNORMALDIFFUSEMAPMATERIAL_IDX             = 20,
-    SBK_QT3DEXTRAS_QNORMALDIFFUSESPECULARMAPMATERIAL_IDX     = 21,
-    SBK_QT3DEXTRAS_QORBITCAMERACONTROLLER_IDX                = 22,
-    SBK_QT3DEXTRAS_QPERVERTEXCOLORMATERIAL_IDX               = 23,
-    SBK_QT3DEXTRAS_QPHONGALPHAMATERIAL_IDX                   = 24,
-    SBK_QT3DEXTRAS_QPHONGMATERIAL_IDX                        = 25,
-    SBK_QT3DEXTRAS_QPLANEGEOMETRY_IDX                        = 26,
-    SBK_QT3DEXTRAS_QPLANEMESH_IDX                            = 27,
-    SBK_QT3DEXTRAS_QSKYBOXENTITY_IDX                         = 28,
-    SBK_QT3DEXTRAS_QSPHEREGEOMETRY_IDX                       = 29,
-    SBK_QT3DEXTRAS_QSPHEREMESH_IDX                           = 30,
-    SBK_QT3DEXTRAS_QSPRITEGRID_IDX                           = 31,
-    SBK_QT3DEXTRAS_QSPRITESHEET_IDX                          = 32,
-    SBK_QT3DEXTRAS_QSPRITESHEETITEM_IDX                      = 33,
-    SBK_QT3DEXTRAS_QTEXT2DENTITY_IDX                         = 34,
-    SBK_QT3DEXTRAS_QTEXTUREMATERIAL_IDX                      = 35,
-    SBK_QT3DEXTRAS_QTORUSGEOMETRY_IDX                        = 36,
-    SBK_QT3DEXTRAS_QTORUSMESH_IDX                            = 37,
-    SBK_QT3DEXTRAS_QT3DWINDOW_IDX                            = 38,
-    SBK_Qt3DExtras_IDX_COUNT                                 = 39
+    SBK_QT3DEXTRAS_QNORMALDIFFUSEMAPALPHAMATERIAL_IDX        = 20,
+    SBK_QT3DEXTRAS_QNORMALDIFFUSEMAPMATERIAL_IDX             = 21,
+    SBK_QT3DEXTRAS_QNORMALDIFFUSESPECULARMAPMATERIAL_IDX     = 22,
+    SBK_QT3DEXTRAS_QORBITCAMERACONTROLLER_IDX                = 23,
+    SBK_QT3DEXTRAS_QPERVERTEXCOLORMATERIAL_IDX               = 24,
+    SBK_QT3DEXTRAS_QPHONGALPHAMATERIAL_IDX                   = 25,
+    SBK_QT3DEXTRAS_QPHONGMATERIAL_IDX                        = 26,
+    SBK_QT3DEXTRAS_QPLANEGEOMETRY_IDX                        = 27,
+    SBK_QT3DEXTRAS_QPLANEMESH_IDX                            = 28,
+    SBK_QT3DEXTRAS_QSKYBOXENTITY_IDX                         = 29,
+    SBK_QT3DEXTRAS_QSPHEREGEOMETRY_IDX                       = 30,
+    SBK_QT3DEXTRAS_QSPHEREMESH_IDX                           = 31,
+    SBK_QT3DEXTRAS_QSPRITEGRID_IDX                           = 32,
+    SBK_QT3DEXTRAS_QSPRITESHEET_IDX                          = 33,
+    SBK_QT3DEXTRAS_QSPRITESHEETITEM_IDX                      = 34,
+    SBK_QT3DEXTRAS_QTEXT2DENTITY_IDX                         = 35,
+    SBK_QT3DEXTRAS_QTEXTUREMATERIAL_IDX                      = 36,
+    SBK_QT3DEXTRAS_QTORUSGEOMETRY_IDX                        = 37,
+    SBK_QT3DEXTRAS_QTORUSMESH_IDX                            = 38,
+    SBK_QT3DEXTRAS_QT3DWINDOW_IDX                            = 39,
+    SBK_Qt3DExtras_IDX_COUNT                                 = 40
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_Qt3DExtrasTypes;
@@ -162,10 +164,10 @@ extern SbkConverter **SbkPySide2_Qt3DExtrasTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QCOMPONENTPTR_IDX        = 0, // QVector<Qt3DCore::QComponent* >
-    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QNODEPTR_IDX             = 1, // QVector<Qt3DCore::QNode* >
-    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QATTRIBUTEPTR_IDX      = 2, // QVector<Qt3DRender::QAttribute* >
-    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QPARAMETERPTR_IDX      = 3, // QVector<Qt3DRender::QParameter* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QATTRIBUTEPTR_IDX      = 0, // QVector<Qt3DRender::QAttribute* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QPARAMETERPTR_IDX      = 1, // QVector<Qt3DRender::QParameter* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QCOMPONENTPTR_IDX        = 2, // QVector<Qt3DCore::QComponent* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QNODEPTR_IDX             = 3, // QVector<Qt3DCore::QNode* >
     SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QFILTERKEYPTR_IDX      = 4, // QVector<Qt3DRender::QFilterKey* >
     SBK_QT3DEXTRAS_QVECTOR_QT3DEXTRAS_QSPRITESHEETITEMPTR_IDX = 5, // QVector<Qt3DExtras::QSpriteSheetItem* >
     SBK_QT3DEXTRAS_QLIST_QVARIANT_IDX                        = 6, // QList<QVariant >
@@ -200,6 +202,7 @@ template<> inline PyTypeObject *SbkType< ::Qt3DExtras::QForwardRenderer >() { re
 template<> inline PyTypeObject *SbkType< ::Qt3DExtras::QGoochMaterial >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QGOOCHMATERIAL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DExtras::QMetalRoughMaterial >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QMETALROUGHMATERIAL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DExtras::QMorphPhongMaterial >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QMORPHPHONGMATERIAL_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DExtras::QNormalDiffuseMapAlphaMaterial >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QNORMALDIFFUSEMAPALPHAMATERIAL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DExtras::QNormalDiffuseMapMaterial >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QNORMALDIFFUSEMAPMATERIAL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DExtras::QNormalDiffuseSpecularMapMaterial >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QNORMALDIFFUSESPECULARMAPMATERIAL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DExtras::QOrbitCameraController >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DExtrasTypes[SBK_QT3DEXTRAS_QORBITCAMERACONTROLLER_IDX]); }
